<?php
/**
 * Classic Business functions and definitions
 *
 * @package Classic Business
 */

if ( ! function_exists( 'classic_business_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function classic_business_setup() {
	global $classic_business_content_width;
	if ( ! isset( $classic_business_content_width ) )
		$classic_business_content_width = 680;

	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles');
	add_theme_support( 'align-wide' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 100,
		'flex-height' => true,
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // twenty_minutes_setup
add_action( 'after_setup_theme', 'classic_business_setup' );

function classic_business_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'classic-business' ),
		'description'   => __( 'Appears on blog page sidebar', 'classic-business' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'classic-business' ),
		'description'   => __( 'Appears on footer', 'classic-business' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-1 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'classic-business' ),
		'description'   => __( 'Appears on footer', 'classic-business' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-2 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'classic-business' ),
		'description'   => __( 'Appears on footer', 'classic-business' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-3 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'classic-business' ),
		'description'   => __( 'Appears on footer', 'classic-business' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-4 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'classic_business_widgets_init' );

add_action( 'wp_enqueue_scripts', 'classic_business_enqueue_styles' );
function classic_business_enqueue_styles() {
    $parenthandle = 'classic-business-style'; // This is 'twentyfifteen-style' for the Twenty Fifteen theme.
    $theme = wp_get_theme();
    wp_enqueue_style( $parenthandle, esc_url(get_template_directory_uri()) . '/style.css',
        array(),  // if the parent theme code has a dependency, copy it to here
        $theme->parent()->get('Version')
    );
    wp_enqueue_style( 'classic-business-child-style', get_stylesheet_uri(),
        array( $parenthandle ),
        $theme->get('Version') // this only works if you have Version in the style header
    );
}

function classic_business_scripts() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'classic_business_scripts' );

function classic_business_enqueue_customizer_css() {
    wp_enqueue_style( 'classic_business-customizer-css', get_stylesheet_directory_uri() . '/css/customize-controls.css' );
}
add_action( 'customize_controls_print_styles', 'classic_business_enqueue_customizer_css' );

add_action( 'customize_register', 'classic_business_customize_register', 11 );
function classic_business_customize_register() {
	global $wp_customize;

	$wp_customize->remove_control( 'twenty_minutes_headerbgcol' );
	$wp_customize->remove_control( 'twenty_minutes_headericoncol' );
	$wp_customize->remove_control( 'twenty_minutes_headertextcol' );
	$wp_customize->remove_section( 'twenty_minutes_social_media_section' );

	$wp_customize->remove_setting( 'twenty_minutes_phone_number' );
	$wp_customize->remove_control( 'twenty_minutes_phone_number' );
	
	$wp_customize->remove_setting( 'twenty_minutes_topbar' );
	$wp_customize->remove_control( 'twenty_minutes_topbar' );
	$wp_customize->remove_setting( 'twenty_minutes_email_address' );
	$wp_customize->remove_control( 'twenty_minutes_email_address' );
	$wp_customize->remove_setting( 'twenty_minutes_fb_link' );
	$wp_customize->remove_control( 'twenty_minutes_fb_link' );
	$wp_customize->remove_setting( 'twenty_minutes_twitt_link' );
	$wp_customize->remove_control( 'twenty_minutes_twitt_link' );
	$wp_customize->remove_setting( 'twenty_minutes_linked_link' );
	$wp_customize->remove_control( 'twenty_minutes_linked_link' );
	$wp_customize->remove_setting( 'twenty_minutes_insta_link' );
	$wp_customize->remove_control( 'twenty_minutes_insta_link' );
	$wp_customize->remove_setting( 'twenty_minutes_youtube_link' );
	$wp_customize->remove_control( 'twenty_minutes_youtube_link' );
	$wp_customize->remove_setting( 'twenty_minutes_copyright_line' );
	$wp_customize->remove_control( 'twenty_minutes_copyright_line' );

}


// Customizer Section
function classic_business_customizer ( $wp_customize ) {

	$wp_customize->add_setting('twenty_minutes_copyright_text',array(
		'default' => 'Business WordPress Theme',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'twenty_minutes_copyright_text', array(
	   'section' 	=> 'twenty_minutes_footer',
	   'label'	 	=> __('Copyright','classic-business'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

    $wp_customize->add_setting('twenty_minutes_copyright_link',array(
		'default' => 'https://www.theclassictemplates.com/wp-themes/free-business-wordpress-theme/',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'twenty_minutes_copyright_link', array(
	   'section' 	=> 'twenty_minutes_footer',
	   'label'	 	=> __('Copyright Link','classic-business'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));


}
add_action( 'customize_register', 'classic_business_customizer' );


// Footer Link
define('classic_business_FOOTER_LINK',__('https://www.theclassictemplates.com/wp-themes/free-business-wordpress-theme/','classic-business'));

if ( ! defined( 'TWENTY_MINUTES_PRO_NAME' ) ) {
	define( 'TWENTY_MINUTES_PRO_NAME', __( 'About Classic Business', 'twenty-minutes' ));
}

if ( ! defined( 'TWENTY_MINUTES_SUPPORT' ) ) {
define('TWENTY_MINUTES_SUPPORT',__('https://wordpress.org/support/theme/classic-business','classic-business'));
}
if ( ! defined( 'TWENTY_MINUTES_REVIEW' ) ) {
define('TWENTY_MINUTES_REVIEW',__('https://wordpress.org/support/theme/classic-business/reviews/','classic-business'));
}
if ( ! defined( 'TWENTY_MINUTES_PRO_DEMO' ) ) {
define('TWENTY_MINUTES_PRO_DEMO',__('https://theclassictemplates.com/demo/classic-business/','classic-business'));
}
if ( ! defined( 'TWENTY_MINUTES_THEME_PAGE' ) ) {
define('TWENTY_MINUTES_THEME_PAGE',__('https://www.theclassictemplates.com/themes/','classic-business'));
}
if ( ! defined( 'TWENTY_MINUTES_PREMIUM_PAGE' ) ) {
define('TWENTY_MINUTES_PREMIUM_PAGE',__('https://www.theclassictemplates.com/wp-themes/business-wordpress-theme/','classic-business'));
}
if ( ! defined( 'TWENTY_MINUTES_THEME_DOCUMENTATION' ) ) {
define('TWENTY_MINUTES_THEME_DOCUMENTATION',__('http://theclassictemplates.com/documentation/classic-business-free/','classic-business'));
}

